package com.gmei

import java.io.Serializable
import org.apache.spark.sql.functions.udf

import com.gmei.WeafareStat.{defaultParams, parser}
import org.apache.spark.sql.{SaveMode, TiContext}
import org.apache.log4j.{Level, Logger}
import scopt.OptionParser
import com.gmei.lib.AbstractParams
import java.io._

import org.apache.spark

object app_list {

  Logger.getLogger("org.apache.spark").setLevel(Level.WARN)
  Logger.getLogger("org.apache.eclipse.jetty.server").setLevel(Level.OFF)

  case class Params(env: String = "dev",
                    date: String = "2018-08-01"
                   ) extends AbstractParams[Params] with Serializable

  val defaultParams = Params()

  val parser = new OptionParser[Params]("Feed_EDA") {
    head("WeafareStat")
    opt[String]("env")
      .text(s"the databases environment you used")
      .action((x, c) => c.copy(env = x))
    opt[String] ("date")
      .text(s"the date you used")
      .action((x,c) => c.copy(date = x))
    note(
      """
        |For example, the following command runs this app on a tidb dataset:
        |
        | spark-submit --class com.gmei.WeafareStat ./target/scala-2.11/feededa-assembly-0.1.jar \
      """.stripMargin +
        s"|   --env ${defaultParams.env}"
    )
  }

  def main(args: Array[String]): Unit = {
    parser.parse(args, defaultParams).map { param =>
      GmeiConfig.setup(param.env)
      val spark_env = GmeiConfig.getSparkSession()
      val sc = spark_env._2

      val ti = new TiContext(sc)
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "diary_video")
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "data_feed_click")
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "blacklist")
      ti.tidbMapTable(dbName = "jerry_test", tableName = "bl_device_list")
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "data_feed_exposure")
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "merge_queue_table")


      import sc.implicits._
      val stat_date = GmeiConfig.getMinusNDate(1)
      println(param.date)
      val partition_date = param.date.replace("-","")
      println(partition_date)

      //自定义udf函数，增加dataframe 列
      val code = (arg: String) => {
        if (arg.getClass.getName == "java.lang.String") partition_date else 0
      }

      val addCol = udf(code)
      //以上为udf函数


      //获取策略命中用户device_id
      val app_list = sc.sql(
        s"""
           |select distinct(cl_id) as device_id,params['installed_app_info'] as app_list
           |from online.tl_hdfs_maidian_view
           |where action="user_installed_all_app_info"
           |and partition_date = '${partition_date}'
         """.stripMargin
      )
      //app_list.show()
      import sc.implicits._
      val rdd_df = app_list.rdd.map(x =>(x(0).toString,x(1).toString))
        .filter(x => x._2.contains("新氧美容")).map(x => x._1).collect().toList.toDF("device_id")
      rdd_df.show()
      rdd_df.createOrReplaceTempView("device_id")

      val temp = sc.sql(
        s"""
           |select *
           |from device_id
         """.stripMargin
      )
      //temp.withColumn("stat_date",addCol(temp("device_id")))

      temp.show()

      GmeiConfig.writeToJDBCTable(temp, "device_id_contain", SaveMode.Append)




    }


  }

}
